'use client';

import { useEffect, useState } from "react";
import { databases } from "../lib/appwrite";
import { databaseId, membersCollectionId } from "../lib/appwrite";
import { getCurrentUserWithRole } from "../utils/auth";
import { Query } from "appwrite";

export default function MemberList() {
  const [members, setMembers] = useState([]);
  const [currentUser, setCurrentUser] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        // Get current user with role first
        const user = await getCurrentUserWithRole();
        setCurrentUser(user);

        // Then fetch members with proper error handling
        const res = await databases.listDocuments(
          databaseId,
          membersCollectionId,
          [Query.orderDesc("$createdAt")] // Optional: sort by creation date
        );
        
        setMembers(res.documents);
      } catch (err) {
        console.error("Error fetching data:", err);
        setError("Failed to load member data");
      } finally {
        setLoading(false);
      }
    };

    fetchData();
  }, []);

  if (loading) {
    return <div className="p-4">Loading members...</div>;
  }

  if (error) {
    return <div className="p-4 text-red-500">{error}</div>;
  }

  return (
    <div className="mt-8 p-4">
      <h2 className="text-xl font-semibold mb-4">All Members</h2>
      
      {/* Current user info */}
      {currentUser && (
        <div className="mb-6 p-4 bg-blue-50 rounded-lg">
          <p className="font-medium">You are logged in as: {currentUser.name}</p>
          <p>Your role: <span className="capitalize font-semibold">{currentUser.role}</span></p>
        </div>
      )}

      {/* Members table */}
      <div className="overflow-x-auto">
        <table className="w-full border">
          <thead>
            <tr className="bg-gray-100">
              <th className="p-3 text-left">Name</th>
              <th className="p-3">Email</th>
              <th className="p-3">Phone</th>
              <th className="p-3">Join Date</th>
              <th className="p-3">Role</th>
            </tr>
          </thead>
          <tbody>
            {members.length > 0 ? (
              members.map((member) => (
                <tr key={member.$id} className="border-t hover:bg-gray-50">
                  <td className="p-3">{member.name || "N/A"}</td>
                  <td className="p-3">{member.email || "N/A"}</td>
                  <td className="p-3">{member.phone || "N/A"}</td>
                  <td className="p-3">
                    {member.joinDate ? new Date(member.joinDate).toLocaleDateString() : "N/A"}
                  </td>
                  <td className="p-3 capitalize">
                    <span className={`px-2 py-1 rounded-full text-xs ${
                      member.role === "admin" 
                        ? "bg-purple-100 text-purple-800" 
                        : "bg-blue-100 text-blue-800"
                    }`}>
                      {member.role || "unknown"}
                    </span>
                  </td>
                </tr>
              ))
            ) : (
              <tr>
                <td colSpan="5" className="p-4 text-center text-gray-500">
                  No members found
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
    </div>
  );
}