"use client";
import { useEffect, useState } from "react";
import { databases } from "../../lib/appwrite";
import { ID } from "appwrite";
import { getCurrentUserWithRole } from "../../utils/auth";

export default function AssignmentsPage() {
  const [assignments, setAssignments] = useState([]);
  const [submissionLinks, setSubmissionLinks] = useState({});
  const [currentUser, setCurrentUser] = useState(null);
  const [loading, setLoading] = useState(true);
  const [newAssignment, setNewAssignment] = useState({
    title: "",
    deadline: ""
  });

  // Fetch assignments and user
  useEffect(() => {
    const fetchData = async () => {
      try {
        const [user, assignmentsResponse] = await Promise.all([
          getCurrentUserWithRole(),
          databases.listDocuments(
            "67e1452b00016444b37f",
            "67f0f285001a1614b4e8"
          )
        ]);
        setCurrentUser(user);
        setAssignments(assignmentsResponse.documents);
      } catch (error) {
        console.error("Error:", error);
      } finally {
        setLoading(false);
      }
    };

    fetchData();
  }, []);

  const handleCreateAssignment = async () => {
    if (!currentUser || currentUser.role !== 'admin') {
      alert("Only admins can create assignments");
      return;
    }

    try {
      await databases.createDocument(
        "67e1452b00016444b37f",
        "67f0f285001a1614b4e8",
        ID.unique(),
        {
          title: newAssignment.title,
          deadline: newAssignment.deadline,
          userId: currentUser.$id, // Add current user's ID
          submitted: false,
          submittedLate: false,
          submittedLink: ""
        }
      );

      // Refresh assignments
      const updated = await databases.listDocuments(
        "67e1452b00016444b37f",
        "67f0f285001a1614b4e8"
      );
      setAssignments(updated.documents);
      setNewAssignment({ title: "", deadline: "" });
      
      alert("Assignment created successfully!");
    } catch (error) {
      console.error("Creation failed:", error);
      alert(`Error: ${error.message}`);
    }
  };

  const handleSubmitAssignment = async (assignmentId) => {
    const link = submissionLinks[assignmentId];
    if (!link) {
      alert("Please provide a submission link");
      return;
    }

    try {
      const isLate = new Date() > new Date(
        assignments.find(a => a.$id === assignmentId).deadline
      );

      await databases.updateDocument(
        "67e1452b00016444b37f",
        "67f0f285001a1614b4e8",
        assignmentId,
        {
          submitted: true,
          submittedLate: isLate,
          submittedLink: link
        }
      );

      // Refresh assignments
      const updated = await databases.listDocuments(
        "67e1452b00016444b37f",
        "67f0f285001a1614b4e8"
      );
      setAssignments(updated.documents);
      setSubmissionLinks({...submissionLinks, [assignmentId]: ""});
      
      alert(`Submission ${isLate ? 'completed (late)' : 'completed on time'}`);
    } catch (error) {
      console.error("Submission failed:", error);
      alert("Submission failed");
    }
  };

  if (loading) return <div>Loading...</div>;

  return (
    <div className="p-4">
      <h1 className="text-2xl font-bold mb-4">Assignments</h1>
      
      {currentUser && (
        <p className="mb-4">Role: <span className="capitalize font-semibold">{currentUser.role}</span></p>
      )}

      {/* Admin-only creation form */}
      {currentUser?.role === 'admin' && (
        <div className="mb-6 p-4 border rounded-lg bg-gray-50">
          <h2 className="text-xl font-semibold mb-4">Create New Assignment</h2>
          <div className="space-y-4">
            <div>
              <label className="block text-sm font-medium mb-1">Title*</label>
              <input
                type="text"
                value={newAssignment.title}
                onChange={(e) => setNewAssignment({...newAssignment, title: e.target.value})}
                className="w-full border px-3 py-2 rounded"
                required
              />
            </div>
            <div>
              <label className="block text-sm font-medium mb-1">Deadline*</label>
              <input
                type="datetime-local"
                value={newAssignment.deadline}
                onChange={(e) => setNewAssignment({...newAssignment, deadline: e.target.value})}
                className="border px-3 py-2 rounded"
                required
              />
            </div>
            <button
              onClick={handleCreateAssignment}
              className="bg-green-600 text-white px-4 py-2 rounded disabled:bg-gray-400"
              disabled={!newAssignment.title || !newAssignment.deadline}
            >
              Create Assignment
            </button>
          </div>
        </div>
      )}

      {/* Assignments list */}
      <div className="space-y-4">
        {assignments.length === 0 ? (
          <p>No assignments available.</p>
        ) : (
          assignments.map((assignment) => (
            <div key={assignment.$id} className="border p-4 rounded-lg">
              <div className="flex justify-between items-start">
                <div>
                  <h2 className="text-xl font-semibold">{assignment.title}</h2>
                  <p className="text-sm text-gray-600 mt-1">
                    Deadline: {new Date(assignment.deadline).toLocaleString()}
                  </p>
                </div>
                {assignment.submitted && (
                  <span className={`px-2 py-1 text-xs rounded-full ${
                    assignment.submittedLate 
                      ? 'bg-red-100 text-red-800' 
                      : 'bg-green-100 text-green-800'
                  }`}>
                    {assignment.submittedLate ? 'Late' : 'Submitted'}
                  </span>
                )}
              </div>

              {!assignment.submitted && currentUser?.role !== 'admin' && (
                <div className="mt-4">
                  <input
                    type="text"
                    placeholder="Paste submission link"
                    value={submissionLinks[assignment.$id] || ""}
                    onChange={(e) => setSubmissionLinks({
                      ...submissionLinks,
                      [assignment.$id]: e.target.value
                    })}
                    className="w-full border px-3 py-2 rounded"
                  />
                  <button
                    onClick={() => handleSubmitAssignment(assignment.$id)}
                    className="mt-2 bg-blue-600 text-white px-4 py-2 rounded"
                    disabled={!submissionLinks[assignment.$id]}
                  >
                    Submit
                  </button>
                </div>
              )}

              {assignment.submitted && assignment.submittedLink && (
                <div className="mt-3">
                  <a 
                    href={assignment.submittedLink} 
                    target="_blank" 
                    rel="noopener noreferrer"
                    className="text-blue-600 hover:underline"
                  >
                    View Submission
                  </a>
                </div>
              )}
            </div>
          ))
        )}
      </div>
    </div>
  );
}