"use client";
import { useEffect, useState } from "react";
import { databases } from "../../lib/appwrite";
import { ID, Query } from "appwrite";
import { getCurrentUserWithRole } from "../../utils/auth";

export default function SubmissionPage() {
  const [assignments, setAssignments] = useState([]);
  const [submissionLink, setSubmissionLink] = useState("");
  const [selectedAssignment, setSelectedAssignment] = useState("");
  const [currentUser, setCurrentUser] = useState(null);
  const [loading, setLoading] = useState(true);

  // Database IDs
  const databaseId = "67e1452b00016444b37f";
  const assignmentsCollectionId = "67f0f285001a1614b4e8";
  const submissionsCollectionId = "67f5ea0a000393d31806";
  const employeeCollectionId = "67f143f00010e2cd2652"; // FSPL HR Employee Management

  useEffect(() => {
    const fetchData = async () => {
      try {
        const [user, assignmentsResponse] = await Promise.all([
          getCurrentUserWithRole(),
          databases.listDocuments(databaseId, assignmentsCollectionId, [
            Query.equal("submitted", false)
          ])
        ]);
        setCurrentUser(user);
        setAssignments(assignmentsResponse.documents);
      } catch (error) {
        console.error("Error:", error);
      } finally {
        setLoading(false);
      }
    };

    fetchData();
  }, []);

  const handleSubmit = async () => {
    if (!selectedAssignment || !submissionLink || !currentUser?.$id) {
      alert("Please fill all required fields");
      return;
    }

    try {
      // 1. Create the submission document
      await databases.createDocument(
        databaseId,
        submissionsCollectionId,
        ID.unique(),
        {
          assignmentId: selectedAssignment,
          userId: currentUser.$id,
          submissionLink
        }
      );

      // 2. Update the assignment status
      const assignment = assignments.find(a => a.$id === selectedAssignment);
      await databases.updateDocument(
        databaseId,
        assignmentsCollectionId,
        selectedAssignment,
        {
          submitted: true,
          submittedLate: new Date() > new Date(assignment.deadline),
          submittedLink: submissionLink
        }
      );

      // 3. Optionally update employee record if needed
      try {
        await databases.updateDocument(
          databaseId,
          employeeCollectionId,
          currentUser.$id, // Assuming document ID matches user ID
          {
            lastSubmission: new Date().toISOString(),
            lastSubmissionLink: submissionLink
          }
        );
      } catch (employeeError) {
        console.log("Employee record not updated (optional):", employeeError);
      }

      alert("Submission successful!");
      setSubmissionLink("");
      setSelectedAssignment("");
      
      // Refresh assignments list
      const updated = await databases.listDocuments(
        databaseId,
        assignmentsCollectionId,
        [Query.equal("submitted", false)]
      );
      setAssignments(updated.documents);
    } catch (error) {
      console.error("Submission failed:", error);
      alert(`Submission failed: ${error.message}`);
    }
  };

  if (loading) return <div className="p-4">Loading...</div>;

  return (
    <div className="p-4">
      <h1 className="text-2xl font-bold mb-6">Submit Assignment</h1>
      
      <div className="space-y-4 max-w-md">
        <div>
          <label className="block text-sm font-medium mb-1">Select Assignment*</label>
          <select
            value={selectedAssignment}
            onChange={(e) => setSelectedAssignment(e.target.value)}
            className="w-full border px-3 py-2 rounded"
            required
          >
            <option value="">-- Select Assignment --</option>
            {assignments.map((assignment) => (
              <option key={assignment.$id} value={assignment.$id}>
                {assignment.title} (Due: {new Date(assignment.deadline).toLocaleDateString()})
              </option>
            ))}
          </select>
        </div>

        <div>
          <label className="block text-sm font-medium mb-1">Submission Link*</label>
          <input
            type="url"
            placeholder="https://github.com/your-repo"
            value={submissionLink}
            onChange={(e) => setSubmissionLink(e.target.value)}
            className="w-full border px-3 py-2 rounded"
            required
          />
          <p className="text-xs text-gray-500 mt-1">GitHub, Gitea, or other repository link</p>
        </div>

        <button
          onClick={handleSubmit}
          className="bg-green-600 text-white px-4 py-2 rounded hover:bg-green-700 disabled:bg-gray-400"
          disabled={!selectedAssignment || !submissionLink}
        >
          Submit Assignment
        </button>
      </div>

      {/* Previous Submissions Section */}
      <div className="mt-8">
        <h2 className="text-xl font-semibold mb-4">Your Submissions</h2>
        <div className="border rounded-lg overflow-hidden">
          <table className="w-full">
            <thead className="bg-gray-100">
              <tr>
                <th className="p-3 text-left">Assignment</th>
                <th className="p-3 text-left">Submission Link</th>
                <th className="p-3 text-left">Submitted At</th>
              </tr>
            </thead>
            <tbody>
              {currentUser?.$id && (
                <SubmissionList 
                  userId={currentUser.$id} 
                  assignments={assignments} 
                />
              )}
            </tbody>
          </table>
        </div>
      </div>
    </div>
  );
}

// Separate component for fetching and displaying submissions
function SubmissionList({ userId, assignments }) {
  const [submissions, setSubmissions] = useState([]);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const fetchSubmissions = async () => {
      try {
        const response = await databases.listDocuments(
          "67e1452b00016444b37f",
          "67f5ea0a000393d31806",
          [Query.equal("userId", userId)]
        );
        setSubmissions(response.documents);
      } catch (error) {
        console.error("Error fetching submissions:", error);
      } finally {
        setLoading(false);
      }
    };

    fetchSubmissions();
  }, [userId]);

  if (loading) return <tr><td colSpan="3" className="p-4 text-center">Loading submissions...</td></tr>;
  if (submissions.length === 0) return <tr><td colSpan="3" className="p-4 text-center">No submissions found</td></tr>;

  return submissions.map((submission) => {
    const assignment = assignments.find(a => a.$id === submission.assignmentId);
    return (
      <tr key={submission.$id} className="border-t hover:bg-gray-50">
        <td className="p-3">{assignment?.title || submission.assignmentId}</td>
        <td className="p-3">
          <a 
            href={submission.submissionLink} 
            target="_blank" 
            rel="noopener noreferrer"
            className="text-blue-600 hover:underline"
          >
            View Submission
          </a>
        </td>
        <td className="p-3">
          {new Date(submission.$createdAt).toLocaleString()}
        </td>
      </tr>
    );
  });
}